<?php declare(strict_types=1);

use BitBadger\PDODocument\{AutoId, Configuration};
use FeedReaderCentral\Data;

/** The current Feed Reader Central version */
const FRC_VERSION = '1.0.0-beta1';

/**
 * Drop .0 or .0.0 from the end of the version to format it for display
 *
 * @return string The version of the application for user display
 */
function display_version(): string {
    [$major, $minor, $rev] = explode('.', FRC_VERSION);
    $minor = $minor == '0' ? '' : ".$minor";
    $rev = match (true) {
        $rev == '0'                 => '',
        str_starts_with($rev, '0-') => substr($rev, 1),
        default                     => ".$rev"
    };
    return "v$major$minor$rev";
}

require __DIR__ . '/vendor/autoload.php';
require 'user-config.php';

Configuration::$pdoDSN = 'sqlite:' . implode(DIRECTORY_SEPARATOR, [__DIR__, 'data', DATABASE_NAME]);
Configuration::$autoId = AutoId::Number;
Data::ensureDb();

/** @var string The date the world wide web was created */
const WWW_EPOCH = '1993-04-30T00:00:00+00:00';

/**
 * Capitalize the first letter of the given string
 *
 * @param string $value The string to be capitalized
 * @return string The given string with the first letter capitalized
 */
function init_cap(string $value): string {
    return match (strlen($value)) {
        0       => "",
        1       => strtoupper($value),
        default => strtoupper(substr($value, 0, 1)) . substr($value, 1),
    };
}
