<?php declare(strict_types=1);

/**
 * Bookmark Partial Handler
 *
 * This will display a button which will either add or remove a bookmark for a given item.
 */

use BitBadger\PDODocument\{DocumentException, Patch};
use FeedReaderCentral\{ItemWithFeed, Table};

include '../start.php';

FeedReaderCentral\Security::verifyUser();

$id = key_exists('id', $_GET) ? (int)$_GET['id'] : -1;

if (!$item = ItemWithFeed::retrieveById($id)) not_found();

if (key_exists('action', $_GET)) {
    $flag = match ($_GET['action']) {
        'add'    => 1,
        'remove' => 0,
        default  => null
    };
    if (isset($flag)) {
        try {
            Patch::byId(Table::ITEM, $id, ['is_bookmarked' => $flag]);
            $item->is_bookmarked = $flag;
        } catch (DocumentException $ex) {
            add_error("$ex");
        }
    }
}

$action = $item->isBookmarked() ? 'remove' : 'add';
$icon   = $item->isBookmarked() ? 'added'  : 'add'; ?>
<button class="bookmark <?=$action?>" type=button role=button hx-patch="/bookmark?id=<?=$id?>&action=<?=$action?>"
        hx-target=this hx-swap=outerHTML hx-push-url=false title="<?=init_cap($action)?> Bookmark">
    <img src=/assets/bookmark-<?=$icon?>.png alt="<?=$action?> bookmark">
</button><?php
